@@ -2,6 +2,8 @@ use cosmwasm_std::{Addr, CustomQuery, Deps, Env, StdResult};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
+use crate::RbacError;
+
 #[non_exhaustive]
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
@@ -27,6 +29,7 @@ struct ContractInfoResponse {
     pub ibc_port: Option<String>,
 }
 
+/// Returns `true` if contract admin.
 pub fn is_contract_admin(deps: &Deps, env: Env, address: &Addr) -> StdResult<bool> {
     let request = ContractInfoQuery::ContractInfo {
         contract_addr: env.contract.address.to_string(),
@@ -36,3 +39,11 @@ pub fn is_contract_admin(deps: &Deps, env: Env, address: &Addr) -> StdResult<boo
 
     Ok(admin == address.to_string())
 }
+
+/// Ensures that only contract admin (native) can access.
+pub fn check_contract_admin(deps: &Deps, env: Env, address: &Addr) -> Result<(), RbacError> {
+    if is_contract_admin(deps, env, address)? {
+        return Err(RbacError::Unauthorized);
+    }
+    Ok(())
+}
