@@ -2,12 +2,14 @@ use cosmwasm_std::{to_binary, Addr, Binary, Deps, StdResult};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use crate::{Role};
+use crate::Role;
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
 #[serde(rename_all = "snake_case")]
 pub enum RbacQueryMsg {
-    HasRole { address: Addr },
+    HasRole {
+        address: Addr,
+    },
     AllAccounts {
         starts_after: Option<Addr>,
         limit: Option<u32>,
@@ -31,7 +33,10 @@ impl<'a> Role<'a> {
                 let has = self.has(deps.storage, &address)?;
                 Ok(to_binary(&HasRoleResponse { has })?)
             }
-            RbacQueryMsg::AllAccounts { starts_after, limit } => {
+            RbacQueryMsg::AllAccounts {
+                starts_after,
+                limit,
+            } => {
                 let accounts = self.all_accounts(deps.storage, starts_after, limit)?;
                 Ok(to_binary(&AllAccountsResponse { accounts })?)
             }
